@@ -31,16 +31,12 @@ package PDF::Kit;
 # --------------------------------------
 # Pragmas
 
-require v5.8.0;
-
 use strict;
 use warnings;
 
-use utf8;  # Convert all UTF-8 to Perl's internal representation.
-
 # --------------------------------------
 # Version
-use version; our $VERSION = qv(v1.0.1);
+use version; our $VERSION = qv(v1.0.2);
 
 # --------------------------------------
 # Exports
@@ -743,7 +739,7 @@ PDF::Kit - A collection of subroutines for PDF::API2.
 
 =head1 VERSION
 
-This document refers to PDF::Kit version v1.0.1
+This document refers to PDF::Kit version v1.0.2
 
 =head1 SYNOPSIS
 
